@@ -3,11 +3,11 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect Musical Modal Functions
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0202';
 
 use Moo;
 use strictures 2;
-use AI::Prolog;
+use AI::Prolog ();
 use Carp qw(croak);
 use MIDI::Util qw(midi_format);
 use Music::Note ();
@@ -15,7 +15,7 @@ use Music::Scales qw(get_scale_notes);
 use namespace::clean;
 
 
-has [qw(chord_note chord mode_note mode mode_function key_note key key_function)] => (
+has [qw(chord_note chord mode_note mode mode_function mode_roman key_note key key_function key_roman)] => (
     is => 'ro',
 );
 
@@ -118,18 +118,19 @@ sub _build__database {
             for my $pitch (@pitches) {
                 my $chord = $self->_modes->{$mode}[$i]{chord};
                 my $function = $self->_modes->{$mode}[$i]{function};
-                $database .= "chord_key($pitch, $chord, $mode_base, $mode, $function).\n";
+                my $roman = $self->_modes->{$mode}[$i]{roman};
+                $database .= "chord_key($pitch, $chord, $mode_base, $mode, $function, $roman).\n";
                 $i++;
             }
         }
     }
     $database .=<<'RULE';
 % Can a chord in one key function in a second?
-pivot_chord_keys(ChordNote, Chord, Key1Note, Key1, Key1Function, Key2Note, Key2, Key2Function) :-
+pivot_chord_keys(ChordNote, Chord, Key1Note, Key1, Key1Function, Key1Roman, Key2Note, Key2, Key2Function, Key2Roman) :-
     % bind the chord to the function of the first key
-    chord_key(ChordNote, Chord, Key1Note, Key1, Key1Function),
+    chord_key(ChordNote, Chord, Key1Note, Key1, Key1Function, Key1Roman),
     % bind the chord to the function of the second key
-    chord_key(ChordNote, Chord, Key2Note, Key2, Key2Function),
+    chord_key(ChordNote, Chord, Key2Note, Key2, Key2Function, Key2Roman),
     % the functions cannot be the same
     Key1Function \= Key2Function.
 RULE
@@ -148,12 +149,13 @@ sub _build__prolog {
 
 sub chord_key {
     my ($self) = @_;
-    my $query = sprintf 'chord_key(%s, %s, %s, %s, %s).',
+    my $query = sprintf 'chord_key(%s, %s, %s, %s, %s, %s).',
         defined $self->chord_note   ? $self->chord_note   : 'ChordNote',
         defined $self->chord        ? $self->chord        : 'Chord',
         defined $self->key_note     ? $self->key_note     : 'KeyNote',
         defined $self->key          ? $self->key          : 'Key',
         defined $self->key_function ? $self->key_function : 'KeyFunction',
+        defined $self->key_roman    ? $self->key_roman    : 'KeyRoman',
     ;
     return $self->_querydb($query);
 }
@@ -161,15 +163,17 @@ sub chord_key {
 
 sub pivot_chord_keys {
     my ($self) = @_;
-    my $query = sprintf 'pivot_chord_keys(%s, %s, %s, %s, %s, %s, %s, %s).',
+    my $query = sprintf 'pivot_chord_keys(%s, %s, %s, %s, %s, %s, %s, %s, %s, %s).',
         defined $self->chord_note    ? $self->chord_note    : 'ChordNote',
         defined $self->chord         ? $self->chord         : 'Chord',
         defined $self->mode_note     ? $self->mode_note     : 'ModeNote',
         defined $self->mode          ? $self->mode          : 'Mode',
         defined $self->mode_function ? $self->mode_function : 'ModeFunction',
+        defined $self->mode_roman    ? $self->mode_roman    : 'ModeRoman',
         defined $self->key_note      ? $self->key_note      : 'KeyNote',
         defined $self->key           ? $self->key           : 'Key',
         defined $self->key_function  ? $self->key_function  : 'KeyFunction',
+        defined $self->key_roman     ? $self->key_roman     : 'KeyRoman',
     ;
     return $self->_querydb($query);
 }
@@ -179,6 +183,7 @@ sub _querydb {
     $self->_prolog->query($query);
     my @return;
     while (my $result = $self->_prolog->results) {
+#warn __PACKAGE__,' L',__LINE__,' R: ',join(',',@$result),"\n";
         push @return, $result;
     }
     return \@return;
@@ -198,7 +203,7 @@ Music::ModalFunction - Inspect Musical Modal Functions
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSIS
 
@@ -211,8 +216,8 @@ version 0.0201
     key_function => 'dominant',
   );
   my $q = $m->chord_key;
-  # [['chord_key','d','maj','g','ionian','dominant'],
-  #  ['chord_key','d','maj','g','lydian','dominant']]
+  # [['chord_key','d','maj','g','ionian','dominant','r_V'],
+  #  ['chord_key','d','maj','g','lydian','dominant','r_V']]
 
   # In what mode(s) can a Gmaj chord function as a subdominant pivot chord?
   $m = Music::ModalFunction->new(
@@ -222,12 +227,12 @@ version 0.0201
     key_function => 'subdominant',
   );
   $q = $m->pivot_chord_keys;
-  # [['pivot_chord_keys','g','maj','c','ionian','dominant','d','dorian','subdominant' ],
-  #  ['pivot_chord_keys','g','maj','c','ionian','dominant','d','ionian','subdominant' ],
-  #  ['pivot_chord_keys','g','maj','c','ionian','dominant','d','mixolydian','subdominant' ],
-  #  ['pivot_chord_keys','g','maj','c','lydian','dominant','d','dorian','subdominant' ],
-  #  ['pivot_chord_keys','g','maj','c','lydian','dominant','d','ionian','subdominant' ],
-  #  ['pivot_chord_keys','g','maj','c','lydian','dominant','d','mixolydian','subdominant' ]]
+  # [['pivot_chord_keys','g','maj','c','ionian','dominant','d','dorian','subdominant','r_IV'],
+  #  ['pivot_chord_keys','g','maj','c','ionian','dominant','d','ionian','subdominant','r_IV'],
+  #  ['pivot_chord_keys','g','maj','c','ionian','dominant','d','mixolydian','subdominant','r_IV'],
+  #  ['pivot_chord_keys','g','maj','c','lydian','dominant','d','dorian','subdominant','r_IV'],
+  #  ['pivot_chord_keys','g','maj','c','lydian','dominant','d','ionian','subdominant','r_IV'],
+  #  ['pivot_chord_keys','g','maj','c','lydian','dominant','d','mixolydian','subdominant','r_IV']]
 
 =head1 DESCRIPTION
 
@@ -235,8 +240,8 @@ C<Music::ModalFunction> allows querying of a musical database of
 Prolog facts and rules that bind notes, chords, modes, keys and
 diatonic functionality.
 
-* Currently there is a database of facts called C<chord_key/5> and one
-rule named C<pivot_chord_keys/8>.
+* Currently there is a database of facts called C<chord_key/6> and one
+rule named C<pivot_chord_keys/10>.
 
 =head1 ATTRIBUTES
 
@@ -250,12 +255,16 @@ rule named C<pivot_chord_keys/8>.
 
 =head2 mode_function
 
+=head2 mode_roman
+
 =head2 key_note
 
 =head2 key
 
 =head2 key_function
 
+=head2 key_roman
+
 =head2 verbose
 
 =head1 METHODS
@@ -274,7 +283,7 @@ Ask the database a question about what chords are in what keys.
 
 Arguments:
 
-  chord_key(ChordNote, Chord, KeyNote, Key, KeyFunction)
+  chord_key(ChordNote, Chord, KeyNote, Key, KeyFunction, KeyRoman)
 
 If defined, the argument in that position will be bound to that value
 (e.g. C<'_'> even). Otherwise an unbound variable is used.
@@ -287,10 +296,10 @@ Ask the database a question about what chords share common keys.
 
 Arguments:
 
-  pivot_chord_keys(ChordNote, Chord, ModeNote, Mode, ModeFunction, KeyNote, Key, KeyFunction)
+  pivot_chord_keys(ChordNote, Chord, ModeNote, Mode, ModeFunction, ModeRoman, KeyNote, Key, KeyFunction, KeyRoman)
 
-If defined, the argument in that position will be bound to that value
-(e.g. C<'_'> even). Otherwise an unbound variable is used.
+If defined, the argument in that position will be bound to that value.
+Otherwise an unbound variable is used.
 
 =head1 SEE ALSO
 
